@@ -3,7 +3,7 @@
 #' @description Compute the deviation of each territorial unit as regards  
 #' to its geographical neighborhood. Neighborhood is defined either
 #' by contiguity order, by a distance value or by a personal matrix (travel time...) 
-#' @param x an sf object or a SpatialPolygonsDataFrame including var1 and var2. 
+#' @param x a sf object including var1 and var2. 
 #' @param var1 name of the numerator variable in x.
 #' @param var2 name of the denominator variable in x.
 #' @param order contiguity order.
@@ -33,8 +33,8 @@
 #' data("GrandParisMetropole")
 #' 
 #' # compute absolute spatial deviation in a neighborhood defined by a contiguity
-#' # order of 2.
-#' com$sdevabs <- sdev(x = com, var1 = "INC", var2 = "TH", order =2, type = "abs")
+#' # order of 1.
+#' com$sdevabs <- sdev(x = com, var1 = "INC", var2 = "TH", order = 1, type = "abs")
 #' 
 #' #compute relative spatial deviation in a neighborhood defined within a distance
 #' # of 5km between communes' centroids
@@ -48,45 +48,28 @@
 #' # travel time of 10 minutes by car
 #' com$scardevrel <- sdev(x = com, var1 = "INC", var2 = "TH", type = "rel", dist = 10, mat = cardist)
 #' 
-#' # map deviations
-#' # set graphical parameters
+#' # relative deviation map
 #' par(mar = c(0,0,1.2,0))
 #' # set breaks
-#' bks <- c(min(com$scardevrel),75,100,125,150,max(com$scardevrel))
-#' # set colot palette
-#' cols <- carto.pal(pal1 = "blue.pal", n1 = 2,
-#'                   pal2 = "wine.pal", n2 = 3)
+#' bks <- c(min(com$scardevrel), 75, 100, 125, 150, max(com$scardevrel))
 #' # plot a choropleth map of the relative spatial deviation
-#' choroLayer(x = com, var = "scardevrel",
-#'            legend.pos = "topleft",
+#' choroLayer(x = com, var = "scardevrel", legend.pos = "topleft",
 #'            legend.title.txt = "Relative Deviation\n(100 = spatial average)",
-#'            breaks = bks, border = NA,
-#'            col = cols)
-#' # add symbols proportional to the absolute spatial deviation
-#' com$sign <- ifelse(test = com$scardevabs<0, yes = "negative", no = "positive")
-#' propSymbolsTypoLayer(x = com, var = "scardevabs",var2 = "sign",
-#'                      legend.var.pos = "left",legend.values.rnd = -2,
-#'                      legend.var2.values.order = c("positive", "negative"),
-#'                      legend.var.title.txt = "Absolute Deviation\n(Income redistribution)",
-#'                      col = c("#ff000050","#0000ff50"),legend.var2.pos = "n",
-#'                      legend.var.style = "e", inches = 0.2)
+#'            breaks = bks, border = NA, 
+#'            col = carto.pal(pal1 = "blue.pal", n1 = 2, pal2 = "wine.pal", n2 = 3))
+#' 
 #' # add EPT boundaries
-#' plot(st_geometry(ept), add=TRUE)
-#' # add a layout
+#' plot(st_geometry(ept), add = TRUE)
+#' 
+#' # layout
 #' layoutLayer(title = "Spatial Deviation (neighborhood : 10 minutes by car)",
 #'             sources = "GEOFLA® 2015 v2.1, Apur, impots.gouv.fr",
-#'             north = TRUE, scale = 5, tabtitle = TRUE, frame = FALSE, theme = "red.pal",
-#'             author = "MTA")
-#' @import sp
+#'             scale = 5, frame = FALSE, author = "MTA", col = "white", 
+#'             coltitle = "black")
 #' @export
 sdev <- function(x, var1, var2, type = "rel", xid,  
                  order, dist, mat){
   
-  # convert to sf object
-  if (methods::is(x, "Spatial")){
-    x <- st_as_sf(x)
-  }
-  
   # Manage id
   if(missing(xid)){xid <- names(x)[1]}
   
