@@ -2,8 +2,8 @@
 #' @name tdev
 #' @description Compute the deviation of each territorial unit as regards  
 #' to an intermediate territorial level of reference. 
-#' @param x a dataframe, an sf object or a SpatialPolygonsDataFrame including 
-#' var1 and var2, and an aggregation key field (territorial belonging).  
+#' @param x a dataframe or a sf object including  var1 and var2 and an 
+#' aggregation key field (territorial belonging).  
 #' @param var1 name of the numerator variable in x.
 #' @param var2 name of the denominator variable in x.
 #' @param key aggregation key field for measuring the deviation (intermediate 
@@ -26,42 +26,49 @@
 #' # load data
 #' data("GrandParisMetropole")
 #' 
-#' # compute absolute territorial deviation (EPT level)
-#' com$tdevabs <- tdev(x = com, var1 = "INC", var2 = "TH", type = "abs", 
-#'                     key = "EPT")
-#' # compute relative territorial deviation (EPT level)
-#' com$tdevrel <- tdev(x = com, var1 = "INC", var2 = "TH", type = "rel", 
-#'                     key = "EPT")
+#' # compute absolute territorial deviation
+#' com$tdevabs <- tdev(x = com, var1 = "INC", var2 = "TH", key = "EPT", 
+#'                     type = "abs")
+#' # compute relative territorial deviation
+#' com$tdevrel <- tdev(x = com, var1 = "INC", var2 = "TH", key = "EPT", 
+#'                     type = "rel")
 #' 
-#' # map deviations
-#' # set graphical parameters
+#' # relative deviation map
 #' par(mar = c(0,0,1.2,0))
 #' # set breaks
-#' bks <- c(min(com$tdevrel),75,100,125,150,max(com$tdevrel))
-#' # set color palette
-#' cols <- carto.pal(pal1 = "blue.pal", n1 = 2,
-#'                   pal2 = "wine.pal", n2 = 3)
+#' bks <- c(min(com$tdevrel), 80, 91, 100, 110, 125, max(com$tdevrel))
 #' # plot a choropleth map of the relative territorial deviation
-#' choroLayer(x = com, var = "tdevrel",
-#'            legend.pos = "topleft",
-#'            breaks = bks, border = NA,
+#' choroLayer(x = com, var = "tdevrel", legend.pos = "topleft",
 #'            legend.title.txt = "Relative Deviation\n(100 = territorial average)",
-#'            col = cols)
-#' # add symbols proportional to the absolute territorial deviation
-#' com$sign <- ifelse(test = com$tdevabs < 0, yes = "negative", no = "positive")
-#' propSymbolsTypoLayer(com, var = "tdevabs", var2 = "sign",
-#'                      legend.var.pos = "left", legend.values.rnd = -2,
-#'                      legend.var2.values.order = c("positive", "negative"),
-#'                      legend.var.title.txt = "Absolute Deviation\n(Income redistribution)",
-#'                      col = c("#ff000050","#0000ff50"), legend.var2.pos = "n",
-#'                      legend.var.style = "e", inches = 0.2)
+#'            breaks = bks, border = NA, 
+#'            col = carto.pal(pal1 = "blue.pal", n1 = 3, pal2 = "wine.pal", n2 = 3))
+#' 
 #' # add EPT boundaries
-#' plot(st_geometry(ept), add=TRUE)
-#' # add a layout
-#' layoutLayer(title = "Territorial Deviation (reference : EPT)",
+#' plot(st_geometry(ept), add = TRUE)
+#' 
+#' # layout
+#' layoutLayer(title = "Territorial Deviation (reference: EPT of belonging)",
 #'             sources = "GEOFLA® 2015 v2.1, Apur, impots.gouv.fr",
-#'             north = TRUE, scale = 5, tabtitle = TRUE, frame = FALSE, theme = "red.pal",
-#'             author = "MTA")
+#'             scale = 5, frame = FALSE, author = "MTA", col = "white", 
+#'             coltitle = "black")
+#' 
+#' 
+#' # absolute deviation map
+#' com$sign <- ifelse(test = com$tdevabs < 0, yes = "Under-Income", no = "Over-Income")
+#' plot(st_geometry(ept))
+#' 
+#' propSymbolsTypoLayer(x = com, var = "tdevabs", var2 = "sign", inches = 0.2,
+#'                      legend.var.title.txt = "Absolute Deviation\n(Income redistribution, euros)",
+#'                      legend.var.pos = "topleft",legend.values.rnd = -2, legend.var.style = "e",
+#'                      legend.var2.title.txt = "Redistribution direction",
+#'                      legend.var2.values.order = c("Under-Income", "Over-Income"),
+#'                      legend.var2.pos = "topright", col = c("#ff0000","#0000ff"))
+#' 
+#' # layout
+#' layoutLayer(title = "Territorial Deviation (reference: EPT of belonging)",
+#'             sources = "GEOFLA® 2015 v2.1, Apur, impots.gouv.fr",
+#'             scale = 5, frame = FALSE,  author = "MTA", col = "white", 
+#'             coltitle = "black")
 #' @export
 tdev <- function(x, var1, var2, type = "rel", key){
   
@@ -69,10 +76,7 @@ tdev <- function(x, var1, var2, type = "rel", key){
   if (methods::is(x, "sf")){
     x <- st_set_geometry(x, NULL)
   }
-  if (methods::is(x, "Spatial")){
-    x <- x@data
-  }
-  
+
   # test for NAs
   vtot <- row.names(x)
   x <- testNAdf(x = x, var1 = var1, var2 = var2)
